@@ -9,6 +9,9 @@ class HandlingResponse:
     defaultError: dict
 
     def __init__(self, valid, data=None, error=None, code_error=None):
+        if valid and data is None:
+            data = {"status": "ok"}
+
         self.data = data
         self.error = error
         self.codeError = code_error
